@@ -1,5 +1,7 @@
 #include "stdafx.h"
 
+#ifdef PCONVERT_EXTENSION
+
 ERROR_T extension_build_params(PyObject *params_py, params *params) {
     size_t index;
     char *key_s, *value_s, value_b;
@@ -349,8 +351,8 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args, PyObject *kwa
     Py_BEGIN_ALLOW_THREADS;
 
     /* validates that both the bottom and the top path are correctly
-    read from the current file system, in case an error occurs return
-    an invalid (none) value to the caller python code */
+    read from the current file system, in case an error occurs an
+    exception should be raised to the caller Python code */
     VALIDATE_PY(
         read_png(bottom_path, demultiply, &bottom),
         Py_BLOCK_THREADS
@@ -537,8 +539,8 @@ PyMethodDef pconvert_functions[3] = {
 
 #if PY_MAJOR_VERSION >= 3
 PyMODINIT_FUNC PyInit_pconvert(void) {
-    /* allocates space for the multiple python object
-    references to be used in the intialization process */
+    /* allocates space for the multiple Python object
+    references to be used in the initialization process */
     PyObject *pconvert_module, *algorithms;
 
     /* allocates space for the version string of the libpng
@@ -552,7 +554,7 @@ PyMODINIT_FUNC PyInit_pconvert(void) {
     pconvert_module = PyModule_Create(&moduledef);
     if(pconvert_module == NULL) { return NULL; }
 
-    /* gathers the information on the currently running libpn version */
+    /* gathers the information on the currently running libpng version */
     libpng_version(libpng_version_s);
 
     /* builds the algorithms tuple that will expose the multiple algorithms
@@ -564,6 +566,8 @@ PyMODINIT_FUNC PyInit_pconvert(void) {
     PyModule_AddStringConstant(pconvert_module, "VERSION", PCONVERT_VERSION);
     PyModule_AddStringConstant(pconvert_module, "COMPILATION_DATE", PCONVERT_COMPILATION_DATE);
     PyModule_AddStringConstant(pconvert_module, "COMPILATION_TIME", PCONVERT_COMPILATION_TIME);
+    PyModule_AddStringConstant(pconvert_module, "COMPILER", PCONVERT_COMPILER);
+    PyModule_AddStringConstant(pconvert_module, "COMPILER_VERSION", PCONVERT_COMPILER_VERSION_STRING);
     PyModule_AddStringConstant(pconvert_module, "LIBPNG_VERSION", libpng_version_s);
     PyModule_AddObject(pconvert_module, "ALGORITHMS", algorithms);
 
@@ -586,7 +590,7 @@ PyMODINIT_FUNC initpconvert(void) {
     pconvert_module = Py_InitModule("pconvert", pconvert_functions);
     if(pconvert_module == NULL) { return; }
 
-    /* gathers the information on the currently running libpn version */
+    /* gathers the information on the currently running libpng version */
     libpng_version(libpng_version_s);
 
     /* builds the algorithms tuple that will expose the multiple algorithms
@@ -598,8 +602,11 @@ PyMODINIT_FUNC initpconvert(void) {
     PyModule_AddStringConstant(pconvert_module, "VERSION", PCONVERT_VERSION);
     PyModule_AddStringConstant(pconvert_module, "COMPILATION_DATE", PCONVERT_COMPILATION_DATE);
     PyModule_AddStringConstant(pconvert_module, "COMPILATION_TIME", PCONVERT_COMPILATION_TIME);
+    PyModule_AddStringConstant(pconvert_module, "COMPILER", PCONVERT_COMPILER);
+    PyModule_AddStringConstant(pconvert_module, "COMPILER_VERSION", PCONVERT_COMPILER_VERSION_STRING);
     PyModule_AddStringConstant(pconvert_module, "LIBPNG_VERSION", libpng_version_s);
     PyModule_AddObject(pconvert_module, "ALGORITHMS", algorithms);
-
 }
 #endif
+
+#endif
