@@ -82,7 +82,7 @@ ERROR_T read_png(char *file_name, char demultiply, struct pcv_image *image) {
     png_uint_32 row_size;
 
     /* opens the file and tests for it being a PNG, this is required
-    to avoid possible problems while handling inproper files */
+    to avoid possible problems while handling improper files */
 #ifdef _MSC_VER
     wchar_t file_name_w[1024];
     swprintf(file_name_w, 1024, L"\\\\?\\%hs", file_name);
@@ -134,7 +134,7 @@ ERROR_T read_png(char *file_name, char demultiply, struct pcv_image *image) {
 
     /* allocates space in memory for the buffer that will
     be used for the "frame" buffer of the image data */
-    row_size = png_get_rowbytes(image->png_ptr, image->info_ptr);
+    row_size = (png_uint_32) png_get_rowbytes(image->png_ptr, image->info_ptr);
     buffer_size = row_size * image->height;
     buffer = (png_byte *) malloc(buffer_size);
 
@@ -166,7 +166,6 @@ ERROR_T write_png_extra(
     int compression,
     int filter
 ) {
-
     /* allocates space for the pointer to the file that is going to
     be used in the writing process of the file */
     FILE *fp;
@@ -653,7 +652,7 @@ ERROR_T copy_image(struct pcv_image *origin, struct pcv_image *target) {
 ERROR_T duplicate_image(struct pcv_image *origin, struct pcv_image *target) {
     int y;
     png_uint_32 rows_size = sizeof(png_bytep) * origin->height;
-    png_uint_32 row_size = png_get_rowbytes(origin->png_ptr, origin->info_ptr);
+    png_uint_32 row_size = (png_uint_32) png_get_rowbytes(origin->png_ptr, origin->info_ptr);
     png_uint_32 buffer_size = row_size * origin->height;
     png_byte *buffer = (png_byte *) malloc(buffer_size);
     copy_image(origin, target);
@@ -849,9 +848,24 @@ ERROR_T popencl(int argc, char **argv) {
     NORMAL;
 }
 
-int main(int argc, char **argv) {
-    set_last_error("%s", "tobias");
+ERROR_T pversion(int argc, char **argv) {
+    char libpng_version_s[16];
+    libpng_version(libpng_version_s);
+    printf(
+        "P(NG)Convert %s (%s %s) [%s %s %d bit] [libpng %s] \n",
+        PCONVERT_VERSION,
+        PCONVERT_COMPILATION_DATE,
+        PCONVERT_COMPILATION_TIME,
+        PCONVERT_COMPILER,
+        PCONVERT_COMPILER_VERSION_STRING,
+        (int) PCONVERT_PLATFORM_CPU_BITS,
+        libpng_version_s
+    );
+    printf("Copyright (c) 2008-2020 Hive Solutions Lda. All rights reserved.\n");
+    NORMAL;
+}
 
+int main(int argc, char **argv) {
     if(argc < 2) {
         abort_("Usage: pconvert <command> [args...]");
         return ERROR;
@@ -865,6 +879,8 @@ int main(int argc, char **argv) {
         EXCEPT_S(pbenchmark(argc, argv));
     } else if(strcmp(argv[1], "opencl") == 0) {
         EXCEPT_S(popencl(argc, argv));
+    } else if(strcmp(argv[1], "version") == 0) {
+        EXCEPT_S(pversion(argc, argv));
     } else {
         abort_("Usage: pconvert <command> [args...]");
         return ERROR;
