@@ -6,11 +6,11 @@ typedef union typem_t {
     char boolean;
     long integer;
     float decimal;
-    char *string;
+    char string[64];
 } typem;
 
 typedef struct param_t {
-    char *key;
+    char key[32];
     union typem_t value;
 } param;
 
